==> quanyi-center-api-1.0.32-20240424.091139-3-sources.jar: cn/com/duiba/quanyi/center/api/utils/wxcoupon/WxCouponAutoCreateUtils.java <==
package cn.com.duiba.quanyi.center.api.utils.wxcoupon;

import cn.com.duiba.quanyi.center.api.utils.StringUtil;
import cn.com.duiba.wolf.utils.DateUtils;

import javax.validation.constraints.NotBlank;
import java.util.List;

/**
 * @author xuzhigang
 * @date 2024/4/8 14:33
 **/
public class WxCouponAutoCreateUtils {
    /**
     * 根据活动预算计算实际金额 公式：活动预算/活动周期 * 14（创建时预留2周的预算），且金额必须是面额的整数倍
     * @param budgetAmount 活动总预算
     * @param couponAmount 面额
     * @param startDate 活动开始时间
     * @param endDate 活动结束时间
     * @param stockDistributePeriod 实际活动周期
     * @return 实际金额（分）
     */
    public static Long calTotalAmount(Long budgetAmount, Long couponAmount, String startDate, String endDate, Integer stockDistributePeriod) {
        // 计算当前2周需要消耗的金额
        long twoWeeksAmount = (budgetAmount / calDiffDays(startDate, endDate, stockDistributePeriod)) * 14;
        // 加款金额必须是面额的整数倍 取余向上取整
        twoWeeksAmount = twoWeeksAmount + (couponAmount - (twoWeeksAmount % couponAmount));
        // 分转换为元 如果两周预算大于总预算 则直接设置为总预算
        return Math.min(budgetAmount, twoWeeksAmount);
    }

    /**
     * 根据活动预算计算最大发放数量 公式：活动预算/活动周期 * 14 / 面额
     * @param budgetAmount 活动总预算
     * @param couponAmount 面额
     * @param startDate 活动开始时间
     * @param endDate 活动结束时间
     * @param stockDistributePeriod 实际活动周期
     * @return 最大发放数量
     */
    public static Integer calMaxNum(Long budgetAmount, Long couponAmount, String startDate, String endDate, Integer stockDistributePeriod) {
        Long totalAmount = calTotalAmount(budgetAmount, couponAmount, startDate, endDate, stockDistributePeriod);
        return Math.toIntExact(totalAmount.intValue() / couponAmount);
    }

    private static Integer calDiffDays(String startDate, String endDate, Integer stockDistributePeriod) {
        if (stockDistributePeriod != null) {
            return stockDistributePeriod;
        }
        return DateUtils.daysBetween(DateUtils.getDayDate(startDate), DateUtils.getDayDate(endDate)) + 1;
    }

    /**
     * 活动名称是否非法（活动名称不能超过9个字符）
     * @param stockName 活动名称
     * @return true-合法 false-非法
     */
    public static boolean isValidStockName(String stockName) {
        return stockName != null && strLength(stockName) <= 18;
    }

    private static int strLength(@NotBlank String value) {
        int valueLength = 0;
        String chinese = "[\u4e00-\u9fa5]";
        for (int i = 0; i < value.length(); i++) {
            String temp = value.substring(i, i + 1);
            if (temp.matches(chinese)) {
                valueLength += 2;
            } else {
                valueLength += 1;
            }
        }
        return valueLength;
    }

    public static boolean oneOrTwo(Integer num) {
        return num != null && (num == 1 || num == 2);
    }

    public static boolean zeroOrOne(Integer num) {
        return num != null && (num == 0 || num == 1);
    }

    public static boolean isValidThemeColor(Integer themeColor) {
        return themeColor != null && themeColor >= 1 && themeColor <= 10;
    }

    public static boolean isValidCardBin(@NotBlank String cardBinList) {
        List<String> cardBins = StringUtil.splitStringWithComma(cardBinList);
        if (cardBins.size() > 100) {
            return false;
        }
        for (String cardBin : cardBins) {
            if (cardBin.length() < 6 || cardBin.length() > 13) {
                return false;
            }
        }
        return true;
    }
}

==> quanyi-center-api-1.0.51-sources.jar: cn/com/duiba/quanyi/center/api/utils/wxcoupon/WxCouponAutoCreateUtils.java <==
package cn.com.duiba.quanyi.center.api.utils.wxcoupon;

import cn.com.duiba.quanyi.center.api.utils.PriceUtils;
import cn.com.duiba.quanyi.center.api.utils.StringUtil;
import cn.com.duiba.wolf.utils.DateUtils;
import org.apache.commons.lang3.StringUtils;

import javax.validation.constraints.NotBlank;
import java.util.List;

/**
 * @author xuzhigang
 * @date 2024/4/8 14:33
 **/
public class WxCouponAutoCreateUtils {
    /**
     * 根据活动预算计算实际金额
     * 公式：活动预算/活动周期 * 14（创建时预留2周的预算），且金额必须是面额的整数倍
     * @param budgetAmount 活动总预算
     * @param couponAmount 面额
     * @param startDate 活动开始时间
     * @param endDate 活动结束时间
     * @param stockDistributePeriod 实际活动周期
     * @return 实际金额（分）
     */
    public static Long calTotalAmount(Long budgetAmount, Long couponAmount, String startDate, String endDate, Integer stockDistributePeriod) {
        // 计算当前2周需要消耗的金额
        long twoWeeksAmount = (budgetAmount / calDiffDays(startDate, endDate, stockDistributePeriod)) * 14;
        // 加款金额必须是面额的整数倍 取余向上取整
        twoWeeksAmount = twoWeeksAmount + (couponAmount - (twoWeeksAmount % couponAmount));
        // 两周预算与10倍面额取最大值，不能超过总预算
        return Math.min(Math.max(budgetAmount, 10 * couponAmount), twoWeeksAmount);
    }

    /**
     * 根据活动预算计算最大发放数量 公式：活动预算/活动周期 * 14 / 面额
     * @param budgetAmount 活动总预算
     * @param couponAmount 面额
     * @param startDate 活动开始时间
     * @param endDate 活动结束时间
     * @param stockDistributePeriod 实际活动周期
     * @return 最大发放数量
     */
    public static Integer calMaxNum(Long budgetAmount, Long couponAmount, String startDate, String endDate, Integer stockDistributePeriod) {
        Long totalAmount = calTotalAmount(budgetAmount, couponAmount, startDate, endDate, stockDistributePeriod);
        return Math.toIntExact(totalAmount.intValue() / couponAmount);
    }

    private static Integer calDiffDays(String startDate, String endDate, Integer stockDistributePeriod) {
        if (stockDistributePeriod != null) {
            return stockDistributePeriod;
        }
        return DateUtils.daysBetween(DateUtils.getDayDate(startDate), DateUtils.getDayDate(endDate)) + 1;
    }

    /**
     * 活动名称是否非法（活动名称不能超过9个字符）
     * @param stockName 活动名称
     * @return true-合法 false-非法
     */
    public static boolean isValidStockName(String stockName) {
        return stockName != null && strLength(stockName) <= 18;
    }

    private static int strLength(@NotBlank String value) {
        int valueLength = 0;
        String chinese = "[\u4e00-\u9fa5]";
        for (int i = 0; i < value.length(); i++) {
            String temp = value.substring(i, i + 1);
            if (temp.matches(chinese)) {
                valueLength += 2;
            } else {
                valueLength += 1;
            }
        }
        return valueLength;
    }

    public static boolean oneOrTwo(Integer num) {
        return num != null && (num == 1 || num == 2);
    }

    public static boolean zeroOrOne(Integer num) {
        return num != null && (num == 0 || num == 1);
    }

    public static boolean isValidThemeColor(Integer themeColor) {
        return themeColor != null && themeColor >= 1 && themeColor <= 10;
    }

    public static boolean isValidCardBin(@NotBlank String cardBinList) {
        List<String> cardBins = StringUtil.splitStringWithComma(cardBinList);
        if (cardBins.size() > 100) {
            return false;
        }
        for (String cardBin : cardBins) {
            if (cardBin.length() < 6 || cardBin.length() > 13) {
                return false;
            }
        }
        return true;
    }

    public static boolean isValidBudgetAmount(String budgetAmount, Long discountAmount) {
        if (StringUtils.isBlank(budgetAmount)) {
            return false;
        }
        Long budget = PriceUtils.convertY2F(budgetAmount);
        return budget % discountAmount == 0;
    }
}
